%++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
%
%  %NAME%    : Classe permettant l'criture rapide d'un rapport type
%              rapport de thse en francais
%  %AUTHOR%  : Cyrille Boullier
%  %EMAIL%   : cyrille.boullier@worldonline.fr
%  %VERSION% : 0.2 (11/10/2004)
%
%    Copyright (C) Cyrille Boullier
%    
%    This program is free software; you can redistribute it and/or
%    modify it under the terms of the GNU General Public License
%    as published by the Free Software Foundation; either version 2
%    of the License, or (at your option) any later version.
%    
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%    
%    You should have received a copy of the GNU General Public License
%    along with this program; if not, write to the Free Software
%    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
%
%
%    The GNU General Public License can be found on the website
%    http://www.fsf.org
%    
%    Les travaux de traduction de la GPL peuvent tre trouvs sur le
%    site : http://www.april.org/gnu/gpl_french.html
%
%++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
\ProvidesClass{These_v0.2}[2004/10/11 v0.2 These class by Cyrille Boullier]
\NeedsTeXFormat{LaTeX2e}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% On veut pouvoir avoir des options :
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Choix entre diffrentes polices :
\newif\ifCompMod\CompModfalse
%%%%% Pour pouvoir choisir si on veut des points dans la toc pour les chapter
\newif\ifDotted\Dottedfalse
%%%%% Pour choisir si on veut faire des listings
\newif\ifListing\Listingfalse

% computer modern : un peu plus cursive que les classiques attention
% pb avec les accents ( est en fait 'e)
\DeclareOption{cm}{\CompModtrue\def\DocFontName{computer modern}}
% Palatino : police assez classique (un peu comme times)
\DeclareOption{palatino}{\def\DocFontName{palatino}}
% Bookman : lettres assez grosses et un peu dcoratives
\DeclareOption{bookman}{\def\DocFontName{bookman}}
% Times : simple fichier trs petit
\DeclareOption{times}{\def\DocFontName{times}}
% type1ec : presque pareil que police cm sans pb d'accents
\DeclareOption{ec}{\def\DocFontName{type1ec}}
% utopia : plus ``arrondie'' que palatino ou times
\DeclareOption{utopia}{\def\DocFontName{utopia}}

%%%%% Autres options :
% option pour supprimer l'indentation en dbut de paragraphe
\DeclareOption{noindent}{\AtEndOfClass{\setlength{\parindent}{0cm}}}

% si l'option n'est pas une cre par moi, la passer  book
\DeclareOption*{%
      \PassOptionsToClass{\CurrentOption}{book}}

% par dfaut on executre en 1er l'option palatino 
\ExecuteOptions{palatino}
% on execute ensuite les options passes par l'utilisateur
\ProcessOptions\relax

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Charger la classe book :
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\LoadClass[11pt,a4paper,twoside,openright]{book}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% On a besoin des packages suivants :
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Pour les polices %%%%%
\RequirePackage[T1]{fontenc}
\ifCompMod
   \RequirePackage[cyr]{aeguill}
   \RequirePackage{type1cm}
\else
   \RequirePackage{\DocFontName}
\fi
%%%%% Pour les "dotted lines" pour chapter %%%%%
\ifDotted
  \RequirePackage{tocloft}
  \renewcommand{\cftchapdotsep}{\cftdotsep}
\fi

%%%%% Pour les listings %%%%%
\ifListing
  \RequirePackage{listings}
  \lstset{numbers=left, stepnumber=1, breaklines=true, frame=single, firstnumber=1, numberstyle=\tiny}
\fi

% Rappel :
% \og et \fg sont utiliss pour les guillemets franaises

%Selection de la langue du document
\RequirePackage[french]{babel}
\selectlanguage{french}
% pour grer l'insertion de figures
\RequirePackage{graphicx}
\DeclareGraphicsExtensions{.pdf,.jpg,.png}
% pour grer le placement des figures (et tableau ...)
\RequirePackage{float}
% pour modifier les marges facilement
\RequirePackage[pdftex,a4paper,centering]{geometry}
\RequirePackage{chngpage}
% pour pouvoir chager la profondeur de toc
\RequirePackage{tocvsec2}
% pour personnaliser les enttes et pieds de page
\RequirePackage{fancyhdr}
% Pour avoir des ``boites'' personalises
\RequirePackage{fancybox}
% pour pouvoir inserer des url
\RequirePackage{url}
% pour avoir des couleurs
\RequirePackage{color}
% Pour crer des tables des matires intermdiaires
\RequirePackage[french]{minitoc}
\setcounter{minitocdepth}{2}

%Type d'encryptage du document (pour l'entre du texte)
\RequirePackage[latin1]{inputenc}

\RequirePackage[sectionbib]{chapterbib}
\RequirePackage[hang, bf, sf]{caption2}

% configuration de la transformation en PDF
\pdfoutput=1
\RequirePackage[pdftex,a4paper,bookmarks=true,bookmarksnumbered=true,plainpages=false,breaklinks=true,colorlinks=true,urlcolor=red,citecolor={blue},linkcolor={blue}]{hyperref}
\pdfcompresslevel=9

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Dfinitions des variables et des macros pour les modifier
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Macro qui permet de crer rapidement de nouvelles commandes
\newcommand{\creecommande}[1]{%
  \expandafter\newcommand\csname #1\endcsname[1]{%
    \@ifundefined{@#1}{}{%
      \ClassWarning{these}{\expandafter\protect\csname
        @#1\endcsname\space est defini plus d'une fois.}}%
    \expandafter\gdef\csname @#1\endcsname{##1}}}

% Macro qui permet d'utiliser une des nouvelle commande
\newcommand{\utilisecommande}[3]{%
  \@ifundefined{@#1}{%
    \ClassWarning{these}{\expandafter\protect\csname
        @#1\endcsname\space n'est pas defini pour l'utilisation de #2}%
  }{%
    #3}%
}

%%%%%%%%%%%%%%%%%
% Pour la these %
%%%%%%%%%%%%%%%%%
% annes de thse
\creecommande {annee}
% nom de l'tudiant
\creecommande {auteur}
% type de rapport (rapport de stage, rapport prliminaire, ...)
\creecommande {typerapport}
% titre de la thse
\creecommande {titre}
% sous-titre de la thse
\creecommande {soustitre}
% nom du logo de l'entreprise
\creecommande {dessintitre}
% directeur de these
\creecommande {directeurthese}
% tuteur de stage
\creecommande {tuteurstage}
% email du thsard
\creecommande {email}
% date de soutenance
\creecommande {datesoutenance}
% lieu de soutenance
\creecommande {lieusoutenance}
% jury de la thse
\creecommande {jury}

%%%%%%%%%%%%%%%%%%%%
% Pour le document %
%%%%%%%%%%%%%%%%%%%%
% mots clefs (mots clefs pour dcrire le rapport)
\creecommande {motscles}
% rsum (contient le rsum du contenu du rapport)
\creecommande {resum}
% entete pour la page de titre classique
\creecommande {entete}

%!!!!!!!!! On peut envisager faire un rsum en anglais !!!!!!!!!

% fin contient le nom qui sera utilis dans les bookmarks pour la partie backmatter
\def\@fin{Conclusion}
\def\fin#1{\def\@fin{#1}}

%%%%%%%%%%%%%%
% Entreprise %
%%%%%%%%%%%%%%
% logo de l'entreprise dans l'entte de page
\creecommande {hlogo}
% nom de l'image logo de entreprise
\creecommande {logoentrep}
% nom entreprise
\creecommande {nomentrep}
% adresse entreprise
\creecommande {addrentrep}

%%%%%%%%%%%%%%
% Universit %
%%%%%%%%%%%%%%
% logo de l'universit
\creecommande {logouniv}
% sigle de l'universit
\creecommande {sigleuniv}
% nom complet univ
\creecommande {nomuniv}
% option tude
\creecommande {optionetude}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% On configure deux trois trucs ...
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Dfinition des marges
\geometry{headheight=0cm,headsep=0cm,footskip=0.7cm,textwidth=21cm,textheight=28cm}
\setlength{\headwidth}{17.5cm}

% Espacement entre les figures et leur lgende
\setlength{\abovecaptionskip}{2mm}
\setlength{\belowcaptionskip}{2mm}

% style sans serif pour les url
\urlstyle{sf}

% Seulement les chapters sont dans les part minitocs
\setcounter{parttocdepth}{0}

% Utilisation des enttes et pieds de pages personnaliss
\pagestyle{fancy}
% Effaage des champs
\fancyhf{}

% Entte droit
\fancyhead[R]{\utilisecommande{hlogo}{fancyhead}{\includegraphics [height=1cm]{figures/\@hlogo}}}

\newlength{\test}
\newlength{\testAdd}

% Entte gauche
\setlength{\test}{0cm}
\setlength{\testAdd}{0cm}

\fancyhead[L]{
%
\addtolength{\test}{\textwidth}
\settowidth{\testAdd}{\sffamily \itshape
Chapitre \thechapter~-~\leftmark}
\addtolength{\test}{-\testAdd}
\addtolength{\test}{-1.5cm}
%
\colorbox{fondFooter}{\textcolor{blue}{\sffamily \itshape
Chapitre \thechapter~-~\leftmark
\hspace{\test}
}}
}


% Pied de page gauche
\setlength{\test}{0cm}
\setlength{\testAdd}{0cm}

\fancyfoot[L]{
%
\addtolength{\test}{\textwidth}
% 
\settowidth{\testAdd}{
\sffamily \itshape
\begin{scriptsize}
\utilisecommande{auteur}{fancyfoot}{\@auteur}
- Octobre 2005
\end{scriptsize}
\thepage
}
% 
\addtolength{\test}{-\testAdd}
%
\colorbox{fondFooter}{\textcolor{blue}{
\sffamily \itshape
\begin{scriptsize}
\utilisecommande{auteur}{fancyfoot}{\@auteur}
- Octobre 2005
\end{scriptsize}
\addtolength{\test}{-12pt}
\hspace{\test}
\thepage}
}
}


% Dfinit une ligne en dessous de l'entete
\renewcommand{\headrulewidth}{0pt}
% Dfinit une ligne au dessus du pied de page
% \renewcommand{\footrulewidth}{0.5pt}


% % Modification des enttes et pieds de page pour les pages de type plain
\fancypagestyle{plain}{%
\fancyhf{}

% Entte droit
\fancyhead[R]{\utilisecommande{hlogo}{fancyhead}{\includegraphics [height=1cm]{figures/\@hlogo}}}

% Entte gauche
\setlength{\test}{0cm}
\setlength{\testAdd}{0cm}

\fancyhead[L]{
%
\addtolength{\test}{\textwidth}
\settowidth{\testAdd}{\sffamily \itshape
\leftmark}
\addtolength{\test}{-\testAdd}
\addtolength{\test}{-1.5cm}
%
\colorbox{fondFooter}{\textcolor{blue}{\sffamily \itshape
\leftmark
\hspace{\test}
}}
}
%

% Pied de page gauche
\setlength{\test}{0cm}
\setlength{\testAdd}{0cm}

\fancyfoot[L]{
%
\addtolength{\test}{\textwidth}
\settowidth{\testAdd}{\sffamily \itshape
\begin{scriptsize}
\utilisecommande{auteur}{fancyfoot}{\@auteur}
- Octobre 2005
\end{scriptsize}
\thepage}
\addtolength{\test}{-\testAdd}
%
\colorbox{fondFooter}{\textcolor{blue}{\sffamily \itshape
\begin{scriptsize}
\utilisecommande{auteur}{fancyfoot}{\@auteur}
- Octobre 2005
\end{scriptsize}
\addtolength{\test}{-15pt}
\hspace{\test}
\thepage}
}}
\renewcommand{\headrulewidth}{0pt}%
}

% utilisation des commandes classiques de page de garde
\title{\@titre}
\author{\@auteur}
\date{\@datesoutenance}

% une profondeur de 3 pour la table des matires
\setcounter{tocdepth}{3}

% Modification du nom de la liste des figures.
% le AtBeginDocument permet de passer aprs les modifications de babel
\AtBeginDocument{\renewcommand{\listfigurename}{Liste des illustrations}}

% Modification du style de page pour les parttoc
\renewcommand{\thispageparttocstyle}{\thispagestyle{plain}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Logos
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\newcommand{\logoentreprise} {
\begin{minipage}{6cm}
\begin{center}
  \utilisecommande{logoentrep}{logoentreprise}{\includegraphics [width=3cm]{figures/\@logoentrep}\\}
  \LARGE{
    \utilisecommande{nomentrep}{logoentreprise}{\textsc{\@nomentrep}\\}
    \utilisecommande{addrentrep}{logoentreprise}{\textit{\@addrentrep}\\}
  }
\end{center}\end{minipage}
\vspace*{5mm}
}

\newcommand{\logoauteur} {
\begin{minipage}{6cm}
\begin{center}
  \LARGE{
    \utilisecommande{auteur}{logoauteur}{\textsc{\@auteur}\\}
    \utilisecommande{sigleuniv}{logoauteur}{\textit{\@sigleuniv}\\}
    \utilisecommande{annee}{logoauteur}{\textit{\@annee}\\}
  }
\end{center}\end{minipage}
\vspace*{5mm}
}

\newcommand{\logouniversite}{
\begin{minipage}{6cm}\begin{center}%
    \utilisecommande{logouniv}{logouniversite}{\includegraphics [width=3cm]{figures/\@logouniv}\\}
    \vspace{2mm}
    \utilisecommande{nomuniv}{logouniversite}{\textsc{\tiny{\@nomuniv}}}
    \vspace{1mm}\\
    \utilisecommande{optionetude}{logouniversite}{\textit{\@optionetude}}
    \vspace{1mm}\\
  \end{center}\end{minipage}}

\newcommand{\logotuteurs}{
  \begin{minipage}{7cm}
    \utilisecommande{tuteurstage}{logotuteur}{Enseignant tuteur~: \@tuteurstage \\}     
    \utilisecommande{directeurthese}{logotuteur}{Matre de stage~: \@directeurthese}
  \end{minipage}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Macros
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% rglage des paramtres pour la cration des pdf
%  mettre dans l'entte du document
\def\docpdf{
\hypersetup{
  pdftitle={\@typerapport},
  pdfauthor={\@auteur},
  pdfsubject={\@titre},
  pdfkeywords={\@motscles}}
}

% \refer produit une rfrence  un document numrot par son numro
% et la page.
% \refer {type de document}{label du document}
\newcommand{\refer}[2]{voir #1 \ref{#2}  la page \pageref{#2}}

%Permet de faire plusieurs rfrences  une mme note de bas de page
% utiliser : \footnote{ma note de bas de page\label{monLabel}}
% puis     : \refmark{antman}
\newcommand{\refmark}[1]{\footnotemark{\ref{#1}}}


% Trace une ligne de 3 cm centre
\newcommand{\ligne}{%
\begin{center}
\begin{minipage}{3cm}
\vspace*{.2mm}
{\hrule height 0.1pt width 3cm}
\vspace*{.2mm}
\end{minipage}
\end{center}}
 
% Insre une figure simplement 
% \fig {nom_fichier}{largeur}{titre}{label}
\newcommand{\fig}[4]{
\begin{figure}
\begin{center}
\includegraphics [width=#2]{#1}
\vspace{2mm}
\captionc{\caption{#3}\label{#4}}{0.9\linewidth}
\end{center}
\end{figure}
}

% Insre une figure avec une rotation de 90 
% \figrotate {nom_fichier}{largeur}{titre}{label}
\newcommand{\figrotate}[4]{
\begin{figure}
\centering \includegraphics [width=#2, angle=90]{#1}
\vspace{2mm}
\captionc{\caption{#3}\label{#4}}{0.9\textwidth}
\end{figure}}

% Insre une figure de la largeur du texte 
% \figautowidth {nom_fichier}{titre}{label}
\newcommand{\figautowidth}[3]{
\begin{figure}[H]
\begin{center}
\includegraphics [width=\textwidth]{figures/#1}
\end{center}
\caption{#2}
\label{#3}
\end{figure}}

% Insre un fichier venant d'un autre rpertoire
% \import{repertoire}{nom_fichier}

\def\import{\begingroup
  \protected@edef\@tempa{\endgroup
    \noexpand\@import{\@ifundefined{input@path}{}{\input@path}}%
    {\@ifundefined{Ginput@path}{}{\Ginput@path}}}%
  \@tempa}
\def\@import#1#2#3#4{%
  \def\input@path{{#3}#1}\def\Ginput@path{{#3}#2}%
  \input{#4}%
  \def\input@path{#1}\ifx\input@path\@empty \let\input@path\@undefined \fi
  \def\Ginput@path{#2}\ifx\Ginput@path\@empty \let\Ginput@path\@undefined \fi
}


% insre la date de compilation et la mention qu'il a t produit avec LaTex
\newcommand{\faitparlatex}{%
  Ce rapport, produit avec \LaTeXe{}, a t compil le~\today.}

% permet de sauter une ligne sans message d'erreur
\newcommand{\NL}{\hfill\newline}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Cre la page de titre
\newcommand{\pagedetitre}{
  \cleardoublepage
    \thispagestyle{empty} \setcounter{page}{-4}
    \begin{center} 
      \begin{minipage}{17.5cm}
      \logoentreprise \hfill \logoauteur
        \begin{center}
          \vfill
        % Double ligne %
        \vspace*{6cm}
        {\hrule height 1.5pt}
        \vspace*{1mm}
        {\hrule height 0.1pt}
        \vspace*{2mm}
        %%%%%%%%%%%%%%%
        \vspace{1cm}
        \utilisecommande{typerapport}{page de titre}{\huge{\textsc{\@typerapport}}\\}
        \utilisecommande{titre}{page de titre}{\Large{\@titre}}
        \vspace{1cm}
        % Double ligne inverse %
        \vspace*{2mm}
        {\hrule height 0.1pt}
        \vspace*{1mm}
        {\hrule height 1.5pt}
        \vspace*{4cm}
        %%%%%%%%%%%%%%%%
        \vfill
      \end{center}
    \end{minipage}\\
    \begin{flushbottom}
      \vfill
      \begin{minipage}{17.5cm}
        \utilisecommande{directeurthese}{page de titre}{Matre de stage~: \@directeurthese}
        \hfill 
        \utilisecommande{tuteurstage}{page de titre}{Enseignant tuteur~: \@tuteurstage}%
      \end{minipage}
    \end{flushbottom}
  \end{center}
}

% Cre la page de titre d'un autre type
% avec le dessintitre centr
\newcommand{\pagedetitrefun}{
  \cleardoublepage%
  \thispagestyle{empty}%
  \setcounter{page}{-3}%
  \begin{center}%
    \begin{minipage}{17.5cm}
      \logoentreprise \hfill \logoauteur
        \vspace*{2cm}
        \begin{center}
          \utilisecommande{typerapport}{pagedetitrefun}{\huge{\textsc{\@typerapport}}\\}
          \Large{\@titre}
         \vspace*{5mm}
         \begin{figure}[H]
            \begin{center}
              \utilisecommande{dessintitre}{pagedetitrefun}{\includegraphics [height=12cm]{figures/\@dessintitre}}
            \end{center}
          \end{figure}
          \vspace*{1cm}
        %%%%%%%%%%%%%%%%
        \end{center}
      \end{minipage}\\
      \begin{flushbottom}
        \vfill
        \begin{minipage}{17.5cm}
          \logotuteurs \hfill \logouniversite
      \end{minipage}
    \end{flushbottom}
  \end{center}
}

% Cre la page de titre classique
\newcommand{\pagedetitreclassique}{
  \cleardoublepage%
  \thispagestyle{empty}%
  \setcounter{page}{-3}%
 \begin{center}
  \begin{minipage}{17.5cm}
    \begin{center}%
      \vspace*{1cm}
      \utilisecommande{nomuniv}{pagedetitreclassique}{\textsc{\large{\@nomuniv}}}\\
      \vspace*{1cm}
      \utilisecommande{entete}{pagedetitreclassique}{\rmfamily{\large{\@entete}}}\\
      \vspace*{0.5cm}
      Directeur de thse: \utilisecommande{directeurthese}{pagedetitreclassique}{\rmfamily{\large{\@directeurthese}}}\\
    \end{center}
  \end{minipage}
  \begin{minipage}{17.5cm}
  \vspace*{3cm}
    \begin{center}
        \utilisecommande{titre}{page de titre classique}{\huge{\@titre}}\\
        \vspace*{0.4cm}
        \utilisecommande{soustitre}{page de titre classique}{{\Large\textit{\@soustitre}}}\\
        \vspace*{0.5cm}
        \utilisecommande{auteur}{page de titre classique}{\Large{\@auteur}}\\
        \vspace*{0.5cm}
        <\utilisecommande{email}{page de titre classique}{\Large{\@email}}>\\
    \end{center}
  \end{minipage}\\
  \vfill
  \begin{flushbottom}
  \begin{minipage}{12.5cm}
    Thse soutenue le \emph{
    \utilisecommande{datesoutenance}{page de titre classique}{\rmfamily{\large{\@datesoutenance}}}
    ,  \utilisecommande{datesoutenance}{page de titre classique}{\rmfamily{\large{\@lieusoutenance}}}
    }\\
    Devant la commission d'examen:\\
    \\
      \begin{tabular}{|l}
        \@jury
      \end{tabular}
  \end{minipage}
  \vspace*{5cm}
  \end{flushbottom}
 \end{center}
}

% Cre la page de garde du style classique Latex
\newcommand{\pagedegarde}{
\thispagestyle{empty} \setcounter{page}{-2} 
\maketitle
}

% Cre la page avec les cadres pour le rsum
% et les mots cls
                                %\newlength{\logowidth} 
                                %\setlength{\logowidth}{\linewidth}
\newcommand{\pagederesume}{%
  \cleardoublepage
  \phantomsection
  \pdfbookmark[0]{Rsum}{pagederesume}%
  \thispagestyle{empty}%
  \setcounter{page}{-1}%
%  \makebox[\logowidth]{\logoentreprise  \hfill  \logoauteur}%
  \makebox[\linewidth]{\logoentreprise  \hfill  \logoauteur}%
  \vspace{\stretch{1}}%
  \begin{center}
    \fboxsep=10pt
    \Ovalbox{%
      \parbox[h][10cm][t]{14.5cm}{%
        \parindent=0pt
        \parskip  =5pt
        {\huge\scshape\bfseries \quad Rsum :\par}
        {\Large\strut \utilisecommande{resum}{pagederesume}{\@resum} \strut\par}}}%
    \par\vspace{1cm}%
    \Ovalbox{%
      \parbox[h][4cm][t]{14.5cm}{%
        \parindent=0pt
        \parskip  =5pt
        {\huge\scshape\bfseries \quad Mots-clefs :\par}
        {\Large\strut \utilisecommande{motscles}{pagederesume}{\@motscles} \strut\par}}}%
  \end{center}%
  \vspace*{\stretch{1}}}

% Cre la page de table des matires
\newcommand{\pagedesmatieres}{
  \cleardoublepage
  \phantomsection
  \pdfbookmark[0]{\contentsname}{pagedesmatieres}
  \dominitoc
  \tableofcontents
}

% Cre la page de liste des figures
\newcommand{\pagedesfigures}{
  \cleardoublepage
  \phantomsection
  \addcontentsline{toc}{chapter}{\listfigurename}
  \listoffigures%
}

% Cre la page de bibliographie
\newcommand{\bibliographie}{
  \cleardoublepage
  \phantomsection
  \addcontentsline{toc}{chapter}{Bibliographie}
}

% Cre la page de liste des tableaux
\newcommand{\pagedestableaux}{
  \cleardoublepage
  \phantomsection
  \addcontentsline{toc}{chapter}{\listtablename}
  \listoftables%
}

%Cre la page de liste des sources de code (listings)
\ifListing
  \renewcommand{\lstlistlistingname}{Liste des codes sources}
  \renewcommand{\lstlistingname}{Source}

  \newcommand{\pagedessources}{
    \cleardoublepage
    \phantomsection
    \addcontentsline{toc}{chapter}{\lstlistlistingname}
    \lstlistoflistings%
  }
\fi

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%    Dfinition de l'aspect des ttes de chapitre      %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Dbut de la zone avec les pages de titre. Ex : 1ere page, page de garde
% page de rsum (non numrotes)
\newcommand\titlematter{%
  \setcounter{part}{-3}%
  \cleardoublepage
  \maxtocdepth{subsection}%
  \settocdepth{subsection}%
  \dominitoc
  \doparttoc
  \@mainmatterfalse}

% Dbut de la zone avec les pages avant le dbut du rapport. Ex :
% remerciments, tables des matires, listes des figures, liste des
% tableaux (pages numrotes en chiffres romains minuscules)
\newcommand\beforefrontmatter{%
  \setcounter{part}{-2}%
  \cleardoublepage
  \pagenumbering{roman}
  \setcounter{page}{1}
  %options de changetext : \changetext{textheight}{textwidth}{evensidemargin}{oddsidemargin}{columnsep}
  \changetext{-5cm}{-3.5cm}{1.5cm}{1.5cm}{0.5cm}
%  \setlength{\bottom}{2cm}
  \setlength{\headheight}{1.5cm}
  \setlength{\headsep}{1cm}
  \setlength{\footskip}{1.5cm}
  \gdef\thechapter{}
  %\geometry{left=3cm,top=1.5cm,right=1.5cm,bottom=2cm,headheight=1.5cm,headsep=1cm,footskip=1.5cm}
}

% Dbut de la zone avec les pages de dbut de rapport. Ex : introduction
% (pages se comportant comme la suite du rapport mais les chapitres ne
% sont pas numrots)
\renewcommand\frontmatter{%
  \newcounter{frontchap}
  \setcounter{frontchap}{1}
  \setcounter{part}{-1}%
  \gdef\thesection{\sffamily \@arabic\c@section}
  \cleardoublepage
  \@mainmatterfalse
  \pagenumbering{arabic}
  \setcounter{page}{1}}

%% Commande de chapitre pour ceux qui se trouvent dans le frontmatter
\newcommand{\frontchapter}[2]{
  \setcounter{section}{0}%
  \chapter{#1}\label{#2}
  \setcounter{chapter}{\c@frontchap}
  \addtocounter{frontchap}{1}
}
  
% Dbut de la zone avec les pages du corp du rapport (pages numrotes
% normalement avec numrotation des chapitres  partir de 1)
\renewcommand\mainmatter{\settocdepth{subsection}%
  \setcounter{part}{0}%
  \setcounter{chapter}{0}
  \gdef\thechapter{\@Alph\c@chapter}
  \gdef\thesection{\texorpdfstring{\textcolor{pink}{\sffamily \thechapter.\@arabic\c@section}}{\sffamily \thechapter.\@arabic\c@section}}
%   \gdef\thesection{\sffamily \thechapter.\@arabic\c@section}
  \gdef\thesubsection{\sffamily \thechapter.\@arabic\c@section.\@arabic\c@subsection}
  \cleardoublepage%
  \@mainmattertrue}

% Dbut de la zone avec la fin du corp du rapport (pages numrotes
% normalement sans numrotation des chapitres)
\renewcommand\backmatter{%
  \cleardoublepage
  \newcounter{backchap}
  \setcounter{backchap}{1}
  \setcounter{chapter}{0}%
  \gdef\thesection{\@arabic\c@section}
  \@mainmatterfalse
\addtocounter{part}{1}
\phantomsection
\pdfbookmark[-1]{\@fin}{\@fin}
\adjustptc
}

\newcommand{\backchapter}[2]{
  \setcounter{section}{0}%
  \chapter{#1}\label{#2}
  \setcounter{chapter}{\c@backchap}
  \addtocounter{backchap}{1}
}
  
% Dbut de la zone avec les pages d'annexe
% Cre la page de dbut des annexes (avec la liste des annexes)
\newcommand{\annexes}{%
%  \adjustptc
  \cleardoublepage
  \settocdepth{chapter}%
  \setcounter{chapter}{0}%
  \setcounter{section}{0}%
  \gdef\@chapapp{\appendixname}%
  \gdef\thechapter{\@Roman\c@chapter}
  \gdef\thesection{\thechapter.\@arabic\c@section}
  \@mainmattertrue  
  % change le nom des part minitocs 
  % ici liste des annexes puisque utilis que pour a  
  \renewcommand{\ptctitle}{Liste des annexes}
  % Pour faire croire qu'il y a une partie annexes  minitoc
  % et par la mme occasion, insrer un lien dans la TOC
  % et dans les bookmarks
  \addtocounter{part}{1}% \setcounter{part}{4}%
  %\mtcaddpart[Annexes]
  \phantomsection
  \addcontentsline{toc}{part}{Annexes}%
  \parttoc
}

% Dbut de la zone avec les pages se trouvant aprs les annexes. Ex :
% bibliographie, remerciements (numrots  la suite des chapitres
% d'avant les annexes)
\newcommand\postappendix{\settocdepth{subsection}%
%  \setcounter{part}{6}%
  \addtocounter{part}{1}%
  \gdef\@chapapp{\chaptername}%
  \gdef\thechapter{\@arabic\c@chapter}
  \gdef\thesection{\@arabic\c@section}
  \@mainmatterfalse}

% Change l'aspect des enttes de chapitre 
% j'ai juste chang le vspace qui tait trop grand
% pour mes gots
\def\@makechapterhead#1{%
  \vspace*{15\p@}%
  {\parindent \z@ \raggedright \normalfont
    \ifnum \c@secnumdepth >\m@ne
      \if@mainmatter
        \huge\bfseries \@chapapp\space \thechapter
        \par\nobreak
        \vskip 20\p@
      \fi
    \fi
    \interlinepenalty\@M
    \Huge \bfseries #1\par\nobreak
    \vskip 40\p@
  }}
\def\@makeschapterhead#1{%
  \vspace*{15\p@}%
  {\parindent \z@ \raggedright
    \normalfont
    \interlinepenalty\@M
    \Huge \bfseries  #1\par\nobreak
    \vskip 40\p@
  }}

% %change l'aspect des titres de section
% \makeatletter
% \renewcommand\section{\@startsection{section}{1}{\z@}%
%   {2cm \@plus -1ex \@minus -.2ex}%
%   {2.3ex \@plus.2ex}%
%   {\reset@font\Large\sffamily\bfseries }}
% \makeatother

% Change l'aspect des sections:
\newcommand{\sectionc}[1]{
\section[\sffamily{#1}]{\sffamily{#1}\textmd{\textcolor{pink}{\hrulefill}}}
}

% Change l'aspect des captions:
\newcommand{\captionc}[2]{
\vspace{\abovecaptionskip}
\fcolorbox{black}{captioncolor}{
\begin{minipage}{#2}
{#1}
\end{minipage}}
\vspace{\belowcaptionskip}
}
  
% Change l'aspect de la rference  un chapitre
\renewcommand{\chaptermark}[1]{\markboth{#1}{}}

% Pour que la reference  un chapitre dans le fichier .toc se fasse
% galement avec le numero de partie (il est alors possible remettre 
% zro les numro de section pour les annexes
\renewcommand\theHchapter{\thepart.\arabic{chapter}}

% Change le style des listes
\renewcommand{\labelitemi}{\textcolor{pink}{\small $\blacklozenge$}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%           Section permettant d'ajouter des commandes      %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\usepackage{amstext}    % utilisation du texte ds les formules math\'{e}matiques
\usepackage{amsmath}    % les symboles les plus fr\'{e}quents
\usepackage{amssymb}    % des symboles
\usepackage{amsfonts}   % des fontes, eg pour \mathbb\usepackage{frenchle}

\usepackage{subfigure}  % Pour l'utilisation de sous-figures.

% Integrations, sommes et fractions
\newcommand{\Int}[2]{\ensuremath{\mathchoice%
    {\displaystyle\int_{#1}^{#2}}
    {\displaystyle\int_{#1}^{#2}}
    {\int_{#1}^{#2}}
    {\int_{#1}^{#2}}
    }}

\newcommand{\Sum}[2]{\ensuremath{\mathchoice%
    {\displaystyle\sum_{#1}^{#2}}
    {\displaystyle\sum_{#1}^{#2}}
    {\sum_{#1}^{#2}}
    {\sum_{#1}^{2}}
    }}



\newcommand{\f}[2]{\ensuremath{\mathchoice%
    {\dfrac{#1}{#2}}
        {\dfrac{#1}{#2}}
    {\frac{#1}{#2}}
    {\frac{#1}{#2}}
    }}

% Plus et moins l'infini
\newcommand{\plus}{\mbox{\raisebox{.2mm}{\tiny{\ensuremath{+}}}}}
\newcommand{\moins}{\mbox{\raisebox{.2mm}{\tiny{\ensuremath{-}}}}}
\newcommand{\pinf}{\plus\ensuremath{\infty}}
\newcommand{\minf}{\moins\ensuremath{\infty}}

% Drivs partielles
\newcommand{\dr}{\ensuremath{\partial}}
\newcommand{\dD}{\ensuremath{\text{d}}}
\newcommand{\dd}[1]{\ensuremath{\:\dD #1}}

% Units en puissance de 10, degrs et exponentielle.
\newcommand{\e}[1]{\times 10^{#1}}
\newcommand{\degr}[1]{\textsuperscript{o}#1}
\newcommand{\Exp}[1]{\exp{\left( #1 \right)}}
\newcommand{\EExp}[1]{e^{ #1 }}

\newcommand{\repere}[2]{
\negthickspace
\underset{#1}{\left\vert
{\vphantom{#2}}
\right.}{#2}
}

\definecolor{prompt}{rgb}{0.0,0.31,0.31}
\definecolor{border}{rgb}{0.44,0.53,0.56}
\definecolor{fond1}{rgb}{0.78,0.88,0.91}
\definecolor{fond2}{rgb}{0.75,0.84,0.88}
\definecolor{fondFooter}{rgb}{0.91,0.92,0.96}
% \definecolor{pink}{rgb}{0.35,0.0,0.59}
\definecolor{pink}{rgb}{0.60,0.0,0.17}
\definecolor{captioncolor}{rgb}{0.95,0.89,0.89}

\newcommand{\coloredBox}[1]{
\begin{center}
\fcolorbox{border}{fond1}{#1}
\end{center}
}
\newcommand{\coloredEqn}[1]{
\begin{equation}
\fcolorbox{border}{fond1}{#1}
\end{equation}
}

\usepackage{multirow}
\newlength{\AccoHaut}
% \setlength{\AccoHaut}{0cm}

\newcommand{\Accolade}[4]{
% \addtolength{\AccoHaut}{\baselineskip}
% \setlength{\AccoHaut}{0.5\baselineskip}
% \setlength{\AccoHaut}{0.5\AccoHaut}
\multirow{#1}{#2}{$\left. \rule{0pt}{#3} \right\}$#4}
}
