# -*- coding: iso-8859-15 -*-
import copy
from scipy.optimize import *
from pylab import *

from facteurStructure import *

iteration=0

def extractPolar(x, p):
    """
    Mthode utilise pour extraire les lments de la matrice de polarisation en fonction du jeu de paramtres p.
    """
    result = []
    for point in x:
        Q = Vector(point['Qh'], point['Qk'], point['Ql'])
        k = Vector(0.27, 0., -1.33)
        H = Q-k
        sattelite = '+'
        
        if round(H.x()%1,2) != 0 or round(H.y()%1,2) != 0 or round(H.z()%1,2) != 0:
            H = Q + k
            sattelite = '-'
        
        if round(H.x()%1,2) != 0 or round(H.y()%1,2) != 0 or round(H.z()%1,2) != 0:
            raise ValueError       
        Pi = point['Pi']
        Pf = point['Pf']
        
        elt_matrice = polarElement(H, sattelite, k, Pi, Pf, p)
        result.append(elt_matrice.real)
    return array(result)

def residuals(p, y, x):
    """
    Rsidus de l'ajustement en fonction du jeu de paramtres p.
    """
    global iteration
    iteration+=1
    print "iteration:" + str(iteration) + ", p:", p
    err = y - extractPolar(x, p)
    return err


def loadData(filename):
    """
    Mthode utilise pour charger les donnes  partir des fichiers exprimentaux
    """
    def addOther(other):
        """
        Traite l'existence de doublons dans le jeu de donnes.
        """
        for elt in result:
            if elt['Qh'] == -other['Qh'] and elt['Qk'] == -other['Qk']  and elt['Ql'] == -other['Ql'] and elt['Pi'] == other['Pi'] and elt['Pf'] == other['Pf']:
                elt['Obs'] = (elt['Obs'] - other['Obs'])/2
                elt['sigma'] = sqrt(elt['sigma']**2 + other['sigma']**2)/2
                return True
        return False
            
    myFile = open(filename, 'r')
    result = []
    myFile.readline()
    for line in myFile:
        line = line.replace('\n','')
        columns = line.split('\t')
        dummy = {}
        dummy['Qh'] = float(columns[0])
        dummy['Qk'] = float(columns[1])
        dummy['Ql'] = float(columns[2])
        dummy['Pi'] = columns[3]
        dummy['Pf'] = columns[4]
        dummy['Obs'] = float(columns[5])
        dummy['sigma'] = float(columns[6])
        
        #Module de Q
        Q = sqrt((dummy['Qh']/a)**2 + (dummy['Ql']/c)**2)
        
        # sinus et cosinus de alpha
        salpha = (dummy['Ql']/c)/Q
        calpha = sqrt(1-salpha**2)
        
        # angle alpha
        dummy['alpha'] = 180./pi*atan(salpha/calpha)

        
        if  not(addOther(dummy)):
            result.append(dummy)
        
    myFile.close()
    return result

# Dfinitions des fichiers de donnes
mesure = []
mesure.append('Data_(0_0_Qc)+.txt')
mesure.append('Data_(1_0_Qc)-.txt')
mesure.append('Data_(3_0_Qc)-.txt')
mesure.append('Data_(2_0_Qc)+.txt')
mesure.append('Data_(1_0_Qc)+.txt')
mesure.append('Data_(2_0_Qc)-.txt')

mesure.append('Data_(0.27_0.0_-1.33)')
mesure.append('Data_(0.27_0.0_1.67)')
mesure.append('Data_(0.27_0.0_4.67)')
mesure.append('Data_(0.27_0.0_7.67)')
mesure.append('Data_(0.27_0.0_10.67)')

mesure.append('Data_(0.73_0.0_-0.67)')
mesure.append('Data_(0.73_0.0_2.33)')
mesure.append('Data_(0.73_0.0_5.33)')
mesure.append('Data_(0.73_0.0_8.33)')
mesure.append('Data_(0.73_0.0_11.33)')

# chargement des donnes
mesure_data = []
for fileName in mesure:
    mesure_data.extend(loadData(fileName))
    
# Dfinition des points exprimentaux servant  l'ajustement
experimental_points = []
experimental_errorbar = []
x_points = []
for index, point in enumerate(mesure_data):
    experimental_points.append(point['Obs'])
    experimental_errorbar.append(point['sigma'])
    x_points.append(index)
experimental_points = array(experimental_points)
experimental_errorbar = array(experimental_errorbar)
x_points = array(x_points)

# p0 = array([6.330, 100.98, 160.00, 6.29, 3.51, -6.35, 1.85]) # Que Pyz
p0 = array([-20.322, 98.19, 140.10, 3.52, 4.16, -2.16, -1.80]) # Toutes les datas

affinement = leastsq(residuals, p0, args=(experimental_points, mesure_data), full_output=0)
print "p = array([%.3f, %.2f, %.2f, %.2f, %.2f, %.2f, %.2f])" % (tuple(affinement[0]))
p0=affinement[0]

# Construction de la liste des rsultats
calculated_points = extractPolar(mesure_data, p0)
# ajoute la valeur calcule dans le dictionnaire de mesures
for index, elt in enumerate(mesure_data):
    elt['calc'] = calculated_points[index]

    
# Gnre le tableaux avec tous les rsultats:
last = {'Qh':0, 'Qk': 0, 'Ql':0}
txt = ''
txt += 'Qh \t Qk \t Ql \t Pi \t Pf \t Observation \t Sigma \t Calcul \t Eccart\n'

for elt in mesure_data:
    current = {'Qh':elt['Qh'], 'Qk': elt['Qh'], 'Ql': elt['Ql']}
    if current['Qh'] != last['Qh'] and current['Qk'] != last['Qk']:
        txt += '\n'
    
    txt += "%.2f %.2f %.2f %s %s %.3f %.3f %.3f %.3f\n"   % (elt['Qh'], elt['Qk'], elt['Ql'], elt['Pi'], elt['Pf'], elt['Obs'], elt['sigma'], elt['calc'], abs(elt['Obs']-elt['calc']))
    last = current


txt_file = open('Results.txt','w')
txt_file.write(txt)
txt_file.close()
