# -*- coding: iso-8859-15 -*-
from math import atan
from Numeric import array, dot, conjugate, zeros, Complex
from Scientific.Geometry.VectorModule import Vector
from pylab import *

# Dfinition des paramtres de maille
a = b =4.966
c = 23.29


def alpha(Q):
    """ determine l'angle alpha entre le vecteur Q et la direction a*
    """
    Qh = Q.x()
    Qk = Q.y()
    Ql = Q.z()
    modQ = sqrt((Qh/a)**2 + (Ql/c)**2)
    salpha = (Ql/c)/modQ
    calpha = sqrt(1.-salpha**2)
    
    return (atan(salpha/calpha), salpha, calpha)

def formFactor(Q, f):
    """
    determine le facteur de forme en fonction du vecteur Q.
    retourne la consante f mais peut-tre utilis
    s'il y a plusieurs type d'atomes magntiques
    """
    return f

def structureFactor(H, sattelite, k, parameters):
    """ determine le facteur de structure au vecteur Q = H \pm k.
         parametres: Les paramtres de l'ajustements
         sattelite: vecteur Q observ.
    """
            
    def model_pseudo_colineaire(H, sattelite, k, parameters):
        """ model pseudo-colinaire"""
        m = 1.
        Phase_1 = parameters[0]*pi/180.
        Phase_ab =  parameters[1]*pi/180.
        Phase_c = parameters[2]*pi/180.
        beta1 = parameters[3]*pi/180.
        beta2 = parameters[4]*pi/180.
        phi1 = parameters[5]*pi/180.
        phi2 = parameters[6]*pi/180.
                
        # Composantes de Fourier du premier rseau de Bravais
        # construction du vecteur mk1
        mab1 = m*Vector(sin(phi1)*cos(beta1), cos(phi1)*cos(beta1), 0.)
        mc1= m*Vector(0.,0.,sin(beta1))
        
        mk1p = mab1 + mc1*exp(-1.j*Phase_1)
        mk1m = Vector(conjugate(mk1p))
        
        # Composantes de Fourier du second rseau de Bravais
        # construction du vecteur mk2
        mab2 = m*Vector(sin(phi2)*cos(beta2), cos(phi2)*cos(beta2), 0.)
        mc2 = m*Vector(0.,0.,sin(beta2))
        
        mk2p = mab2*exp(-1.j*Phase_ab) + mc2*exp(-1.j*(Phase_c+Phase_1))
        mk2m = Vector(conjugate(mk2p))
        
        if sattelite == '+':
            return (mk1p, mk2p)
        else:
            return (mk1m, mk2m)
    
    mk1, mk2 = model_pseudo_colineaire(H, sattelite, k, parameters)
    
    z = 1/6.
    r1 = Vector(0., 0., z)  # Premier rseau de Bravais
    r2 = Vector(2./3., 1./3., 1./3. + z)
    r3 = Vector(1./3., 2./3., 2./3. + z)
    
    r4 = Vector(0., 0., -z) # Premier rseau de Bravais
    r5 = Vector(2./3., 1./3., 1./3. - z)
    r6 = Vector(1./3., 2./3., 2./3. - z)
        
    # Somme sur les atomes de la premire zone de brillouin
    if sattelite == '+':
        Q = H + k
    else:
        Q = H - k
    Fm = Vector()
    Fm   = (mk1*exp(1.j*Q*r1*2*pi))
    Fm += (mk2*exp(1.j*Q*r5*2*pi))
    
    return Fm
    
def Mperp(H, sattelite, k, parameters):
    """
    Definit le vecteur interaction magnetique perpendiculaire au vecteur Q
    dans le repere (X,Y,Z) associe a Q.
    """
    Fm = structureFactor(H, sattelite, k, parameters)
    if sattelite == '+':
        Q = H + k
    else:
        Q = H - k
    alph, salpha, calpha = alpha(Q)

    M=Vector(0, Fm.x()*salpha - Fm.z()*calpha,  Fm.y())
    
    return M
    
def sigmaMy(M):
    """
    Definit la composante selon y de la section efficace
    de diffusion magnetique sigmaM.
    """
    sMy = M.y()*conjugate(M.y())
    return sMy
    
def sigmaMz(M):
    """
    Definit la composante selon z de la section efficace
    de diffusion magnetique sigmaM.
    """
    sMz = M.z()*conjugate(M.z())
    return sMz
    
def sigma0(M):
    """ Definit la section efficace totale.
    """
    return sigmaMy(M) +sigmaMz(M)

def chiralTerm(M):
    """ Definit le terme chiral.
    """
    return 1j*Vector(conjugate(M)).cross(M).x()
    
def magneticTerm(M):
    """ Definit le terme magnetic-magnetic
    """
    return M.y()*conjugate(M.z()) + conjugate(M.y())*M.z()
    
def polarElement(H, sattelite, k, Pi, Pf, parameters):
    """
    Definit la matrice de polarisation.
    C'est ici qu'on passe les paramtres du modle qui seront
    utilis pour le calcul du facteur de structure.
    """
    #Valeur moyenne de la polarisation incidente sur l'ensemble des donnes
    P0 = 0.9188

    
    polars = {'X':0, 'Y':1, 'Z':2}
            
    M = Mperp(H, sattelite, k, parameters)
    sigma = sigma0(M)
    
    if polars[Pi] == 0 and polars[Pf] ==0:
        eltMatrice = -P0*(sigmaMy(M) + sigmaMz(M))
    if polars[Pi] == 0 and polars[Pf] ==1:
        eltMatrice = 0
    if polars[Pi] == 0 and polars[Pf] ==2:
        eltMatrice = 0
    if polars[Pi] == 1 and polars[Pf] ==0:
        eltMatrice = chiralTerm(M)
    if polars[Pi] == 1 and polars[Pf] ==1:
        eltMatrice = P0*(sigmaMy(M) - sigmaMz(M))
    if polars[Pi] == 1 and polars[Pf] ==2:
        eltMatrice = P0*magneticTerm(M)
    if polars[Pi] == 2 and polars[Pf] ==0:
        eltMatrice = chiralTerm(M)
    if polars[Pi] == 2 and polars[Pf] ==1:
        eltMatrice = P0*magneticTerm(M)
    if polars[Pi] == 2 and polars[Pf] ==2:
        eltMatrice = -P0*(sigmaMy(M) - sigmaMz(M))
        
    return eltMatrice/sigma